<?php

namespace App\Controller;

use App\Entity\User;
use Doctrine\ORM\EntityManager;
use Doctrine\ORM\EntityManagerInterface;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\IsGranted;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

#[IsGranted('ROLE_USER')]
class CalendarController extends AbstractController
{
    #[Route('/', name: 'calendar')]
    public function index(): Response
    {
        return $this->render('calendar/index.html.twig', [
            'controller_name' => 'CalendarController',
        ]);
    }

    #[Route('/calendar/receive', name: 'calendar_receive')]
    public function calendarReceive()
    {
        $user = $this->getUser();
        if (!$user || !$user instanceof User)
        {
            throw new \LogicException("The calendar could not be sent because there are no existing user.");
        }

        $calendar = $user->getCalendarFile();

        return new JsonResponse($calendar);
    }

    #[Route('/calendar/send', name: 'calendar_send')]
    public function calendarSend(Request $request, EntityManagerInterface $manager)
    {
        $json = $request->getContent();
        $calendar = json_decode($json, true);

        /** @var User */
        $user = $this->getUser();
        if (!$user || !$user instanceof User)
        {
            throw new \LogicException("The calendar could not be sent because there are no existing user.");
        }

        $user->setCalendarFile($calendar);
        $manager->flush();

        return new Response("all good");
    }
}
